@@ -1,8 +1,13 @@
 BASE_URL = "http://censius-logs-prod1.us-east-1.elasticbeanstalk.com/v1"
 AMS_URL = "http://ams-prod.us-east-1.elasticbeanstalk.com"
 MONITORS_PROGRAMMATIC_BASE_URL = (
-    "http://monitors-env.eba-ptkdpfrn.us-east-1.elasticbeanstalk.com/v1/programmatic"
+    "http://monitors-prod.us-east-1.elasticbeanstalk.com//v1/programmatic"
 )
+# BASE_URL = "http://censiuslogs-dev.us-east-1.elasticbeanstalk.com/v1"
+# AMS_URL = "http://ams-dev0.us-east-1.elasticbeanstalk.com"
+# MONITORS_PROGRAMMATIC_BASE_URL = (
+#     "http://monitors-env.eba-ptkdpfrn.us-east-1.elasticbeanstalk.com/v1/programmatic"
+# )
 
 # Models
 REGISTER_MODEL_URL = lambda: f"{AMS_URL}/models/register"
