@@ -105,6 +105,18 @@ class BulkLogsValidation:
                 f"  ValidationError: <timestamp_column>='{timestamp_column}' has null values, <timestamp_column> must be NOT NULL",
             )
 
+        try:
+            input[timestamp_column] = input.apply(
+                lambda x: x[timestamp_column] * 1000
+                if len(str(x[timestamp_column])) == 10
+                else x[timestamp_column],
+                axis=1,
+            )
+        except:
+            return (
+                True,
+                f"  ValidationError: <timestamp_column>='{timestamp_column}' has to be of type int64 or float64, and is supposed to be in milliseconds, example: 1620000000000",
+            )
         # if timestamp_column cannot be converted to datetime return error
         try:
             input["timestamp_val"] = pd.to_datetime(input[timestamp_column], unit="ms")
@@ -514,5 +526,5 @@ def bulk_col_renaming_map_for_exp(
     for register_col in registered_dataset_to_datatype.keys():
         if register_col.lower() in registered_model_target:
             continue
-        input_map[registered_to_provided[register_col]] = "shap_" + register_col.lower()
+        input_map[registered_to_provided[register_col]] = register_col.lower()
     return input_map
